From a55809959fb47c9f5cb52fdf58134f718e67555e Mon Sep 17 00:00:00 2001
From: Dave Syer
Date: Thu, 23 Jan 2014 09:44:04 +0000
Subject: [PATCH] Fix type mentioned in javadocs
---
.../listener/ConfigFileApplicationListener.java | 8 +++-----
.../context/listener/LoggingApplicationListener.java | 12 ++++++------
.../context/listener/VcapApplicationListener.java | 5 ++---
3 files changed, 11 insertions(+), 14 deletions(-)
diff --git a/spring-boot/src/main/java/org/springframework/boot/context/listener/ConfigFileApplicationListener.java b/spring-boot/src/main/java/org/springframework/boot/context/listener/ConfigFileApplicationListener.java
index 0b90e807ac..db27bc6b20 100644
--- a/spring-boot/src/main/java/org/springframework/boot/context/listener/ConfigFileApplicationListener.java
+++ b/spring-boot/src/main/java/org/springframework/boot/context/listener/ConfigFileApplicationListener.java
@@ -36,7 +36,6 @@ import org.springframework.boot.bind.RelaxedDataBinder;
import org.springframework.boot.config.PropertiesPropertySourceLoader;
import org.springframework.boot.config.PropertySourceLoader;
import org.springframework.boot.config.YamlPropertySourceLoader;
-import org.springframework.context.ApplicationContextInitializer;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.AnnotatedBeanDefinitionReader;
import org.springframework.context.annotation.PropertySources;
@@ -58,10 +57,9 @@ import org.springframework.util.DigestUtils;
import org.springframework.util.StringUtils;
/**
- * {@link ApplicationContextInitializer} that configures the context environment by
- * loading properties from well known file locations. By default properties will be loaded
- * from 'application.properties' and/or 'application.yml' files in the following
- * locations:
+ * {@link ApplicationListener} that configures the context environment by loading
+ * properties from well known file locations. By default properties will be loaded from
+ * 'application.properties' and/or 'application.yml' files in the following locations:
*
* - classpath:
* - file:./
diff --git a/spring-boot/src/main/java/org/springframework/boot/context/listener/VcapApplicationListener.java b/spring-boot/src/main/java/org/springframework/boot/context/listener/VcapApplicationListener.java
index ffa3c23801..0f6832e973 100644
--- a/spring-boot/src/main/java/org/springframework/boot/context/listener/VcapApplicationListener.java
+++ b/spring-boot/src/main/java/org/springframework/boot/context/listener/VcapApplicationListener.java
@@ -29,7 +29,6 @@ import org.apache.commons.logging.LogFactory;
import org.springframework.boot.SpringApplicationEnvironmentAvailableEvent;
import org.springframework.boot.config.JsonParser;
import org.springframework.boot.config.JsonParserFactory;
-import org.springframework.context.ApplicationContextInitializer;
import org.springframework.context.ApplicationListener;
import org.springframework.core.Ordered;
import org.springframework.core.env.CommandLinePropertySource;
@@ -40,8 +39,8 @@ import org.springframework.core.env.PropertiesPropertySource;
import org.springframework.util.StringUtils;
/**
- * An {@link ApplicationContextInitializer} that knows where to find VCAP (a.k.a. Cloud
- * Foundry) meta data in the existing environment. It parses out the VCAP_APPLICATION and
+ * An {@link ApplicationListener} that knows where to find VCAP (a.k.a. Cloud Foundry)
+ * meta data in the existing environment. It parses out the VCAP_APPLICATION and
* VCAP_SERVICES meta data and dumps it in a form that is easily consumed by
* {@link Environment} users. If the app is running in Cloud Foundry then both meta data
* items are JSON objects encoded in OS environment variables. VCAP_APPLICATION is a
diff --git a/spring-boot/src/main/java/org/springframework/boot/context/listener/LoggingApplicationListener.java b/spring-boot/src/main/java/org/springframework/boot/context/listener/LoggingApplicationListener.java
index e25208ce30..c2682afa2e 100644
--- a/spring-boot/src/main/java/org/springframework/boot/context/listener/LoggingApplicationListener.java
+++ b/spring-boot/src/main/java/org/springframework/boot/context/listener/LoggingApplicationListener.java
@@ -30,8 +30,8 @@ import org.springframework.boot.SpringApplicationEnvironmentAvailableEvent;
import org.springframework.boot.SpringApplicationStartEvent;
import org.springframework.boot.logging.LogLevel;
import org.springframework.boot.logging.LoggingSystem;
-import org.springframework.context.ApplicationContextInitializer;
import org.springframework.context.ApplicationEvent;
+import org.springframework.context.ApplicationListener;
import org.springframework.context.event.SmartApplicationListener;
import org.springframework.core.env.ConfigurableEnvironment;
import org.springframework.core.env.Environment;
@@ -41,11 +41,11 @@ import org.springframework.util.MultiValueMap;
import org.springframework.util.ResourceUtils;
/**
* An {@link ApplicationContextInitializer} that configures a logging framework depending
* on what it finds on the classpath and in the {@link Environment}. If the environment
* contains a property logging.config then that will be used to initialize
* the logging system, otherwise a default location is used. The classpath is probed for
* log4j and logback and if those are present they will be reconfigured, otherwise vanilla
* java.util.logging will be used.
*
*
@@ -41,11 +41,11 @@ import org.springframework.util.MultiValueMap;
import org.springframework.util.ResourceUtils;
/**
- * An {@link ApplicationContextInitializer} that configures a logging framework depending
- * on what it finds on the classpath and in the {@link Environment}. If the environment
- * contains a property logging.config then that will be used to initialize
- * the logging system, otherwise a default location is used. The classpath is probed for
- * log4j and logback and if those are present they will be reconfigured, otherwise vanilla
+ * An {@link ApplicationListener} that configures a logging framework depending on what it
+ * finds on the classpath and in the {@link Environment}. If the environment contains a
+ * property logging.config then that will be used to initialize the logging
+ * system, otherwise a default location is used. The classpath is probed for log4j and
+ * logback and if those are present they will be reconfigured, otherwise vanilla
* java.util.logging will be used.
*